# 1004

From Wikipedia, the free encyclopedia

Year 1004 (MIV) was a leap year starting on Saturday (link will display the full calendar) of the Julian calendar.

## Events[edit]

### By place[edit]

#### Africa[edit]

- An episode of plague and famine breaks out in North Africa.[1]

#### Asia[edit]

- December – The Samanid dynasty ends in Bokhara.
- The Liao dynasty launches a major offensive against the Song dynasty. Their armies meet near Shanyang, north of the Song capital of Kaifeng.
- Battle of Shanzhou: The Liao dynasty general Xiao Talin is picked off, by an elite Song Chinese crossbow sniper.
- Jingdezhen porcelain enters a period of significant production.

#### Europe[edit]

- May 14 – Henry II is crowned King of Italy at Pavia. A quarrel between his German companions and the Pavese erupts into a full-scale battle.
- Henry II launches a war against Bolesław of Poland (which lasts until 1018).
- Boleslaus I of Poland loses Bohemia, after having become duke the previous year. He is succeeded as Duke of Bohemia by Jaromir.
- Sancho III becomes king of Navarre, Aragon and Castille.
- Sweyn I of Denmark destroys Norwich.
- Aberdeen becomes a bishopric.
- The Arabs sack Pisa.
- The troops of Vizier Al-Mansur sack the Catalan city of Manresa.[2]
- Pope John XVIII begins his reign (or 1003).

## Births[edit]

- Abdallah ibn Al-Aftas (approximate date) (d. 1060)
- Goda of England (d. 1055)

## Deaths[edit]

- November 13 – Abbo of Fleury
- Adelaide of Aquitaine, queen of France, wife of Hugh Capet
- Erik the Red (or 1003) (b. 950)
- Garcia IV of Pamplona
- Li Jiqian, Tangut jiedushi who ruled the new Western Xia Dynasty in northwestern China (b. 963)